@@ -23,38 +23,38 @@ test_that("predict_race works", {
 
   expect_equal(smith$likely_race, "white")
   expect_equal(perez$likely_race, "hispanic")
-  expect_equal(lucky$likely_race, "black, white")
+  expect_equal(lucky$likely_race, "white")
   expect_equal(predict_race("smith", probability = FALSE)$likely_race, "white")
-  expect_equal(smith$probability_american_indian, 0.0089)
-  expect_equal(smith$probability_asian, 0.005)
-  expect_equal(smith$probability_black, 0.2311)
-  expect_equal(smith$probability_hispanic, 0.024)
-  expect_equal(smith$probability_white, 0.709)
-  expect_equal(smith$probability_2races, 0.0219)
+  expect_equal(smith$probability_american_indian, 0.0087)
+  expect_equal(smith$probability_asian, 0.0045)
+  expect_equal(smith$probability_black, 0.2267)
+  expect_equal(smith$probability_hispanic, 0.0199)
+  expect_equal(smith$probability_white, 0.7211)
+  expect_equal(smith$probability_2races, 0.0191)
 
 
-  expect_equal(lucky$probability_american_indian, 0.0078)
-  expect_equal(lucky$probability_asian, 0.0621)
-  expect_equal(lucky$probability_black, 0.436)
-  expect_equal(lucky$probability_hispanic, 0.0291)
-  expect_equal(lucky$probability_white, 0.436)
-  expect_equal(lucky$probability_2races, 0.0291)
+  expect_equal(lucky$probability_american_indian, 0.0061)
+  expect_equal(lucky$probability_asian, 0.042)
+  expect_equal(lucky$probability_black, 0.4466)
+  expect_equal(lucky$probability_hispanic, 0.0231)
+  expect_equal(lucky$probability_white, 0.4544)
+  expect_equal(lucky$probability_2races, 0.0279)
 
   expect_equal(smith_lincoln$likely_race, c("white", "white"))
   expect_equal(predict_race(c("smith", "Lincoln"), probability = FALSE)$likely_race,
                c("white", "white"))
   expect_equal(smith_lincoln$probability_american_indian,
-               c(0.0089, 0.0368))
+               c(0.0087, 0.0373))
   expect_equal(smith_lincoln$probability_asian,
-               c(0.005, 0.0135))
+               c(0.0045, 0.0125))
   expect_equal(smith_lincoln$probability_black,
-               c(0.2311, 0.1471))
+               c(0.2267, 0.1421))
   expect_equal(smith_lincoln$probability_hispanic,
-               c(0.024, 0.0251))
+               c(0.0199, 0.0215))
   expect_equal(smith_lincoln$probability_white,
-               c(0.709, 0.749))
+               c(0.7211, 0.7615))
   expect_equal(smith_lincoln$probability_2races,
-               c(0.0219, 0.0285))
+               c(0.0191, 0.025))
 
 
   expect_true(is.na(ben_smith$likely_race))
@@ -70,12 +70,12 @@ test_that("predict_race works", {
 
   expect_equal(lincoln$likely_race, "white")
   expect_equal(predict_race("Lincoln", probability = FALSE)$likely_race, "white")
-  expect_equal(lincoln$probability_american_indian, 0.0368)
-  expect_equal(lincoln$probability_asian, 0.0135)
-  expect_equal(lincoln$probability_black, 0.1471)
-  expect_equal(lincoln$probability_hispanic, 0.0251)
-  expect_equal(lincoln$probability_white, 0.749)
-  expect_equal(lincoln$probability_2races, 0.0285)
+  expect_equal(lincoln$probability_american_indian, 0.0373)
+  expect_equal(lincoln$probability_asian, 0.0125)
+  expect_equal(lincoln$probability_black, 0.1421)
+  expect_equal(lincoln$probability_hispanic, 0.0215)
+  expect_equal(lincoln$probability_white, 0.7615)
+  expect_equal(lincoln$probability_2races, 0.025)
 
   expect_true(is.na(rlincoln$likely_race))
   expect_true(is.na(predict_race("RLincoln", probability = FALSE)$likely_race))
